@@ -446,6 +446,34 @@ class TcbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeActivityRecord(self, request):
+        """查询活动记录信息
+
+        :param request: Request instance for DescribeActivityRecord.
+        :type request: :class:`tencentcloud.tcb.v20180608.models.DescribeActivityRecordRequest`
+        :rtype: :class:`tencentcloud.tcb.v20180608.models.DescribeActivityRecordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeActivityRecord", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeActivityRecordResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAuthDomains(self, request):
         """获取安全域名列表
 
@@ -922,6 +950,34 @@ class TcbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeEnvPostpaidDeduct(self, request):
+        """查询环境后付费计费详情
+
+        :param request: Request instance for DescribeEnvPostpaidDeduct.
+        :type request: :class:`tencentcloud.tcb.v20180608.models.DescribeEnvPostpaidDeductRequest`
+        :rtype: :class:`tencentcloud.tcb.v20180608.models.DescribeEnvPostpaidDeductResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeEnvPostpaidDeduct", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeEnvPostpaidDeductResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeEnvs(self, request):
         """获取环境列表，含环境下的各个资源信息。尤其是各资源的唯一标识，是请求各资源的关键参数
 
@@ -1149,6 +1205,34 @@ class TcbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSpecialCostItems(self, request):
+        """查询环境1分钱抵扣信息
+
+        :param request: Request instance for DescribeSpecialCostItems.
+        :type request: :class:`tencentcloud.tcb.v20180608.models.DescribeSpecialCostItemsRequest`
+        :rtype: :class:`tencentcloud.tcb.v20180608.models.DescribeSpecialCostItemsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeSpecialCostItems", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSpecialCostItemsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeWxCloudBaseRunEnvs(self, request):
         """查询微信云托管环境信息
 
@@ -1457,6 +1541,34 @@ class TcbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ReplaceActivityRecord(self, request):
+        """更新活动详情
+
+        :param request: Request instance for ReplaceActivityRecord.
+        :type request: :class:`tencentcloud.tcb.v20180608.models.ReplaceActivityRecordRequest`
+        :rtype: :class:`tencentcloud.tcb.v20180608.models.ReplaceActivityRecordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ReplaceActivityRecord", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ReplaceActivityRecordResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RollUpdateCloudBaseRunServerVersion(self, request):
         """针对特定的版本，进行滚动更新
 
